plugins

package
v0.0.0-...-2a2e17e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2020 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Accumulator

type Accumulator interface {
	AddFields(measurement string,
		fields map[string]interface{},
		tags map[string]string,
		t ...time.Time)

	// AddGauge is the same as AddFields, but will add the metric as a "Gauge" type
	AddGauge(measurement string,
		fields map[string]interface{},
		tags map[string]string,
		t ...time.Time)

	// AddCounter is the same as AddFields, but will add the metric as a "Counter" type
	AddCounter(measurement string,
		fields map[string]interface{},
		tags map[string]string,
		t ...time.Time)

	// SetPrecision sets the timestamp rounding precision.  All metrics addeds
	// added to the accumulator will have their timestamp rounded to the
	// nearest multiple of precision.
	SetPrecision(precision time.Duration)

	// Report an error.
	AddError(err error)
}

type AggregatingOutput

type AggregatingOutput interface {
	Output
	Add(in internal.Metric)
	Push() []internal.Metric
	Reset()
}

type Input

type Input interface {
	SampleConfig() string

	Description() string

	Gather(Accumulator) error
}

type Output

type Output interface {
	Connect() error
	Close() error
	Description() string
	SampleConfig() string
	Write(metrics []internal.Metric) error
}

Directories

Path Synopsis
all
cpu
disk
* https://github.com/influxdata/telegraf/tree/master/plugins/inputs/disk
* https://github.com/influxdata/telegraf/tree/master/plugins/inputs/disk
mem
net
all

Jump to